@@ -118,13 +118,14 @@ class ThreadedBufferingBase(BufferingBase):
 
 
 class TestProcess(BufferingBase if fcntl else ThreadedBufferingBase):
-    def __init__(self, *args):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('env', os.environ)
         self.proc = subprocess.Popen(
             args,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            env=os.environ,
             bufsize=1,
+            **kwargs
         )
         super(TestProcess, self).__init__(self.proc.stdout)
 
